package com.link.core.modules.excel;

import com.link.base.basic.model.ListOfValue;
import com.link.core.modules.excel.XssfExcelHelper;
import java.io.File;
import java.lang.reflect.Field;
import java.util.ArrayList;
import java.util.Date;
import java.util.Iterator;
import java.util.List;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

public abstract class ExcelHelper {

   private static final Logger logger = LogManager.getLogger(ExcelHelper.class);
   public static final String UID = "serialVersionUID";


   public List readExcel(Class clazz, int sheetNo, boolean hasTitle) throws Exception {
      Field[] fields = clazz.getDeclaredFields();
      String[] fieldNames = new String[fields.length];

      for(int i = 0; i < fields.length; ++i) {
         String fieldName = fields[i].getName();
         fieldNames[i] = fieldName;
      }

      return this.readExcel(clazz, fieldNames, sheetNo, hasTitle);
   }

   public List readExcel(Class clazz, String[] fieldNames, boolean hasTitle) throws Exception {
      return this.readExcel(clazz, fieldNames, 0, hasTitle);
   }

   public abstract List readExcel(Class var1, String[] var2, int var3, boolean var4) throws Exception;

   public void writeExcel(Class clazz, List dataModels) throws Exception {
      Field[] fields = clazz.getDeclaredFields();
      String[] fieldNames = new String[fields.length];

      for(int i = 0; i < fields.length; ++i) {
         String fieldName = fields[i].getName();
         fieldNames[i] = fieldName;
      }

      this.writeExcel(clazz, dataModels, fieldNames, fieldNames);
   }

   public void writeExcel(Class clazz, List dataModels, String[] fieldNames) throws Exception {
      this.writeExcel(clazz, dataModels, fieldNames, fieldNames);
   }

   public abstract void writeExcel(Class var1, List var2, String[] var3, String[] var4) throws Exception;

   protected boolean isDateType(Class clazz, String fieldName) {
      boolean flag = false;

      try {
         Field field = clazz.getDeclaredField(fieldName);
         Object typeObj = field.getType().newInstance();
         flag = typeObj instanceof Date;
      } catch (Exception var6) {
         ;
      }

      return flag;
   }

   protected boolean isDoubleType(Class clazz, String fieldName) {
      boolean flag = false;

      try {
         Field field = clazz.getDeclaredField(fieldName);
         if(field.getType() == Double.class) {
            flag = true;
         }
      } catch (Exception var5) {
         ;
      }

      return flag;
   }

   protected Object parseValueWithType(String value, Class type) {
      Object result = null;

      try {
         if(Boolean.class == type) {
            result = Boolean.valueOf(Boolean.parseBoolean(value));
         } else if(Byte.class == type) {
            result = Byte.valueOf(Byte.parseByte(value));
         } else if(Short.class == type) {
            result = Short.valueOf(Short.parseShort(value));
         } else if(Integer.class == type) {
            result = Integer.valueOf(Integer.parseInt(value));
         } else if(Long.class == type) {
            result = Long.valueOf(Long.parseLong(value));
         } else if(Float.class == type) {
            result = Float.valueOf(Float.parseFloat(value));
         } else if(Double.class == type) {
            result = Double.valueOf(Double.parseDouble(value));
         } else {
            result = value;
         }
      } catch (Exception var5) {
         ;
      }

      return result;
   }

   public static void main(String[] args) {
      ArrayList params = new ArrayList();
      ListOfValue listOfValue = new ListOfValue();
      listOfValue.setName("张三");
      listOfValue.setVal("1234");
      params.add(listOfValue);
      String[] titles = new String[]{"显示值", "独立源代码"};
      String[] fieldNames = new String[]{"name", "val"};

      try {
         File e = new File("D:\\POI2007.xlsx");
         XssfExcelHelper eh3 = XssfExcelHelper.getInstance((File)e);
         eh3.writeExcel(ListOfValue.class, params, fieldNames, titles);
         List list = eh3.readExcel(ListOfValue.class, fieldNames, true);
         Iterator var8 = list.iterator();

         while(var8.hasNext()) {
            ListOfValue record = (ListOfValue)var8.next();
            System.out.println(record);
         }
      } catch (Exception var10) {
         logger.error("ExcelHelper捕获异常: ", var10);
      }

   }

}
